export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export ARCH="aarch64"
export PREFIX="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export BUILD_PREFIX="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export SYS_PREFIX="/home/ktietz/anaconda3"
export SYS_PYTHON="/home/ktietz/anaconda3/bin/python"
export SUBDIR="linux-aarch64"
export build_platform="linux-aarch64"
export SRC_DIR="/home/ktietz/src/ci_nxt/maven_1623258974518/work"
export ROOT="/home/ktietz/anaconda3"
export CONDA_PY="39"
export PY3K="1"
export PY_VER="3.9"
export STDLIB_DIR="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.9"
export SP_DIR="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.9/site-packages"
export NPY_VER="1.16"
export CONDA_NPY="116"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.26"
export CONDA_PERL="5.26"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="maven"
export PKG_VERSION="3.8.1"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/home/ktietz/src/aggregate/maven-feedstock/recipe"
export CPU_COUNT="32"
export LANG="de_DE.UTF-8"
export SHLIB_EXT=".so"
export PATH="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac:/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac:/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/home/ktietz/anaconda3/bin:/home/ktietz/anaconda3/condabin:/usr/local/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/home/ktietz/.local/bin:/home/ktietz/bin"
export HOME="/home/ktietz"
export PKG_CONFIG_PATH="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib"
export BUILD="aarch64-conda_cos7-linux-gnu"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
export ignore_build_only_deps="{'numpy', 'python'}"
export extend_keys="{'pin_run_as_build', 'ignore_build_only_deps', 'extend_keys', 'ignore_version'}"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export cxx_compiler="gxx"
export clang_variant="clang"
export lzo="2"
export cyrus_sasl="2.1.26"
export libffi="3.3"
export channel_targets="defaults"
export openblas="0.3.10"
export serf="1.3.9"
export fortran_compiler_version="10.2.0"
export geos="3.8.0"
export gnu="2.12.2"
export libpng="1.6"
export hdfeos2="2.20"
export rust_compiler="rust"
export hdfeos5="5.1"
export cpu_optimization_target="nocona"
export hdf4="4.2"
export libwebp="1.0.0"
export libtiff="4.1"
export python_implementation="cpython"
export pixman="0.40"
export proj="6.2.1"
export macos_min_version="10.9"
export target_platform="linux-aarch64"
export fontconfig="2.13"
export VERBOSE_CM="VERBOSE=1"
export zlib="1.2"
export dbus="1"
export icu="68"
export llvm_variant="llvm"
export cdt_name="amzn2"
export macos_machine="x86_64-apple-darwin13.4.0"
export c_compiler="gcc"
export expat="2.2"
export boost="1.73"
export libxml2="2.9"
export libxslt="1.1"
export giflib="5"
export rust_compiler_version="1.46.0"
export sqlite="3"
export freetype="2.10"
export qtwebkit="true"
export glib="2"
export apr="1.6.3"
export jpeg="9"
export gst_plugins_base="1.14"
export libgd="2.2.5"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export cairo="1.16"
export r_base="3.5"
export fortran_compiler="gfortran"
export openjpeg="2.3"
export r_implementation="mro-base"
export openssl="1.1.1"
export gmp="6.1"
export readline="8.1"
export mpfr="4"
export tk="8.6"
export libgdal="3.0"
export VERBOSE_AT="V=1"
export libgsasl="1.8"
export libkml="1.3"
export mkl="2021"
export boost_cpp="1.73"
export noarch_python="python"
export r_version="3.5.0"
export harfbuzz="2.4"
export libdap4="3.19"
export hdf5="1.10.6"
export libprotobuf="3.14.0"
export proj4="5.2.0"
export g2clib="1.6"
export python_impl="cpython"
export libnetcdf="4.6"
export cxx_compiler_version="10.2.0"
export xz="5"
export blas_impl="openblas"
export bzip2="1.0"
export c_compiler_version="10.2.0"
export gstreamer="1.14"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/home/ktietz/src/ci_nxt/maven_1623258974518/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/home/ktietz/anaconda3/bin/python' -m conda shell.bash hook)"
conda activate  "/home/ktietz/src/ci_nxt/maven_1623258974518/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
