if [ -z ${CONDA_BUILD+x} ]; then
    source /home/ktietz/src/ci_nxt/maven_1623258974518/work/build_env_setup.sh
fi
#!/bin/bash

target=$PREFIX/opt/maven
mkdir -p $target
mkdir -p $PREFIX/bin

cp -r * $target
cd $PREFIX/bin
ln -s ../opt/maven/bin/* .

rm -fr $target/lib/ext/

